onTransition method
- @protected
- @mustCallSuper
- Bloc bloc,
- Transition transition
inherited
Called whenever a transition occurs in any bloc with the given bloc
and transition.
A transition occurs when a new event is added
and a new state is emitted from a corresponding EventHandler.
onTransition is called before a bloc's state has been updated.
Implementation
@protected
@mustCallSuper
void onTransition(
Bloc<dynamic, dynamic> bloc,
Transition<dynamic, dynamic> transition,
) {}