GroupFieldBloc<T extends FieldBloc<FieldBlocStateBase>, ExtraData> class
Methods
-
addError(Object error, [StackTrace? stackTrace])
→ void
-
Reports an
error which triggers onError with an optional StackTrace.
inherited
-
close()
→ Future<void>
-
Closes the instance.
This method should be called when the instance is no longer needed.
Once close is called, the instance can no longer be used.
inherited
-
emit(GroupFieldBlocState<T, ExtraData> state)
→ void
-
Updates the
state to the provided state.
emit does nothing if the state being emitted
is equal to the current state.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(Change<GroupFieldBlocState<T, ExtraData>> change)
→ void
-
Called whenever a
change occurs with the given change.
A change occurs when a new state is emitted.
onChange is called before the state of the cubit is updated.
onChange is a great spot to add logging/analytics for a specific cubit.
inherited
-
onError(Object error, StackTrace stackTrace)
→ void
-
Called whenever an
error occurs and notifies BlocObserver.onError.
inherited
-
removeFormBloc(FormBloc formBloc)
→ void
-
See FieldBloc.removeFormBloc
inherited
-
toString()
→ String
-
A string representation of this object.
override
-
Updates the
extraData of the current state.
See SingleFieldBloc.updateExtraData
inherited
-
updateFormBloc(FormBloc formBloc, {bool autoValidate = false})
→ void
-
See FieldBloc.updateFormBloc
inherited
-
validate()
→ Future<bool>
-
Validate the field.
If does not contain
fieldBlocs returns true otherwise
if one of them returns false it fails
inherited